# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/desired_state/model/entity.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.common_config import task_pb2 as prodvana_dot_common__config_dot_task__pb2
from prodvana.proto.prodvana.desired_state.model import desired_state_pb2 as prodvana_dot_desired__state_dot_model_dot_desired__state__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)prodvana/desired_state/model/entity.proto\x12\x1cprodvana.desired_state.model\x1a!prodvana/common_config/task.proto\x1a\x30prodvana/desired_state/model/desired_state.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb6\t\n\x06\x45ntity\x12\x34\n\x02id\x18\x01 \x01(\x0b\x32(.prodvana.desired_state.model.Identifier\x12\x18\n\x10\x64\x65sired_state_id\x18\x02 \x01(\t\x12\x1d\n\x15root_desired_state_id\x18\x03 \x01(\t\x12>\n\x0b\x61nnotations\x18\x04 \x01(\x0b\x32).prodvana.desired_state.model.Annotations\x12\x34\n\x06status\x18\x05 \x01(\x0e\x32$.prodvana.desired_state.model.Status\x12\x41\n\rsimple_status\x18\x11 \x01(\x0e\x32*.prodvana.desired_state.model.SimpleStatus\x12;\n\x0estarting_state\x18\x06 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12<\n\x0flast_seen_state\x18\x07 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12:\n\rdesired_state\x18\x08 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x39\n\x0ctarget_state\x18\x13 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12K\n\x15precondition_statuses\x18\t \x03(\x0b\x32,.prodvana.desired_state.model.ConditionState\x12L\n\x13status_explanations\x18\n \x03(\x0b\x32/.prodvana.desired_state.model.StatusExplanation\x12\x34\n\x04logs\x18\x0b \x03(\x0b\x32&.prodvana.desired_state.model.DebugLog\x12K\n\x12\x61\x63tion_explanation\x18\x0c \x01(\x0b\x32/.prodvana.desired_state.model.ActionExplanation\x12\x39\n\x15last_update_timestamp\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12:\n\x16last_fetched_timestamp\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12:\n\x16last_applied_timestamp\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12>\n\x0c\x64\x65pendencies\x18\x10 \x03(\x0b\x32(.prodvana.desired_state.model.Identifier\x12\x38\n\tlifecycle\x18\x12 \x01(\x0e\x32%.prodvana.common_config.TaskLifecycle\x12G\n\x10missing_approval\x18\x14 \x01(\x0b\x32-.prodvana.desired_state.model.MissingApproval\"}\n\x0b\x45ntityGraph\x12\x36\n\x04root\x18\x01 \x01(\x0b\x32(.prodvana.desired_state.model.Identifier\x12\x36\n\x08\x65ntities\x18\x02 \x03(\x0b\x32$.prodvana.desired_state.model.EntityBXZVgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/desired_state/modelb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.desired_state.model.entity_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZVgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/desired_state/model'
  _globals['_ENTITY']._serialized_start=194
  _globals['_ENTITY']._serialized_end=1400
  _globals['_ENTITYGRAPH']._serialized_start=1402
  _globals['_ENTITYGRAPH']._serialized_end=1527
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/secrets/secrets_manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from prodvana.proto.prodvana.common_config import env_pb2 as prodvana_dot_common__config_dot_env__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&prodvana/secrets/secrets_manager.proto\x12\x14prodvana.environment\x1a\x1cgoogle/api/annotations.proto\x1a prodvana/common_config/env.proto\x1a\x17validate/validate.proto\"\x10\n\x0eListSecretsReq\"B\n\x0fListSecretsResp\x12/\n\x07secrets\x18\x01 \x03(\x0b\x32\x1e.prodvana.common_config.Secret\"-\n\x15ListSecretVersionsReq\x12\x14\n\x03key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"*\n\x16ListSecretVersionsResp\x12\x10\n\x08versions\x18\x01 \x03(\t\"<\n\x0cSetSecretReq\x12\x14\n\x03key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x16\n\x05value\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\" \n\rSetSecretResp\x12\x0f\n\x07version\x18\x01 \x01(\t\"\'\n\x0f\x44\x65leteSecretReq\x12\x14\n\x03key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\x12\n\x10\x44\x65leteSecretResp\"H\n\x16\x44\x65leteSecretVersionReq\x12\x14\n\x03key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07version\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\x19\n\x17\x44\x65leteSecretVersionResp2\xbe\x05\n\x0eSecretsManager\x12t\n\x0bListSecrets\x12$.prodvana.environment.ListSecretsReq\x1a%.prodvana.environment.ListSecretsResp\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/v1/secrets/list\x12\x95\x01\n\x12ListSecretVersions\x12+.prodvana.environment.ListSecretVersionsReq\x1a,.prodvana.environment.ListSecretVersionsResp\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/v1/secrets/{key=*}/versions\x12l\n\tSetSecret\x12\".prodvana.environment.SetSecretReq\x1a#.prodvana.environment.SetSecretResp\"\x16\x82\xd3\xe4\x93\x02\x10\"\x0b/v1/secrets:\x01*\x12\x81\x01\n\x0c\x44\x65leteSecret\x12%.prodvana.environment.DeleteSecretReq\x1a&.prodvana.environment.DeleteSecretResp\"\"\x82\xd3\xe4\x93\x02\x1c*\x1a/v1/secrets/{key=*}/delete\x12\xab\x01\n\x13\x44\x65leteSecretVersion\x12,.prodvana.environment.DeleteSecretVersionReq\x1a-.prodvana.environment.DeleteSecretVersionResp\"7\x82\xd3\xe4\x93\x02\x31*//v1/secrets/{key=*}/versions/{version=*}/deleteBLZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/secretsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.secrets.secrets_manager_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/secrets'
  _LISTSECRETVERSIONSREQ.fields_by_name['key']._options = None
  _LISTSECRETVERSIONSREQ.fields_by_name['key']._serialized_options = b'\372B\004r\002\020\001'
  _SETSECRETREQ.fields_by_name['key']._options = None
  _SETSECRETREQ.fields_by_name['key']._serialized_options = b'\372B\004r\002\020\001'
  _SETSECRETREQ.fields_by_name['value']._options = None
  _SETSECRETREQ.fields_by_name['value']._serialized_options = b'\372B\004r\002\020\001'
  _DELETESECRETREQ.fields_by_name['key']._options = None
  _DELETESECRETREQ.fields_by_name['key']._serialized_options = b'\372B\004r\002\020\001'
  _DELETESECRETVERSIONREQ.fields_by_name['key']._options = None
  _DELETESECRETVERSIONREQ.fields_by_name['key']._serialized_options = b'\372B\004r\002\020\001'
  _DELETESECRETVERSIONREQ.fields_by_name['version']._options = None
  _DELETESECRETVERSIONREQ.fields_by_name['version']._serialized_options = b'\372B\004r\002\020\001'
  _SECRETSMANAGER.methods_by_name['ListSecrets']._options = None
  _SECRETSMANAGER.methods_by_name['ListSecrets']._serialized_options = b'\202\323\344\223\002\022\022\020/v1/secrets/list'
  _SECRETSMANAGER.methods_by_name['ListSecretVersions']._options = None
  _SECRETSMANAGER.methods_by_name['ListSecretVersions']._serialized_options = b'\202\323\344\223\002\036\022\034/v1/secrets/{key=*}/versions'
  _SECRETSMANAGER.methods_by_name['SetSecret']._options = None
  _SECRETSMANAGER.methods_by_name['SetSecret']._serialized_options = b'\202\323\344\223\002\020\"\013/v1/secrets:\001*'
  _SECRETSMANAGER.methods_by_name['DeleteSecret']._options = None
  _SECRETSMANAGER.methods_by_name['DeleteSecret']._serialized_options = b'\202\323\344\223\002\034*\032/v1/secrets/{key=*}/delete'
  _SECRETSMANAGER.methods_by_name['DeleteSecretVersion']._options = None
  _SECRETSMANAGER.methods_by_name['DeleteSecretVersion']._serialized_options = b'\202\323\344\223\0021*//v1/secrets/{key=*}/versions/{version=*}/delete'
  _globals['_LISTSECRETSREQ']._serialized_start=153
  _globals['_LISTSECRETSREQ']._serialized_end=169
  _globals['_LISTSECRETSRESP']._serialized_start=171
  _globals['_LISTSECRETSRESP']._serialized_end=237
  _globals['_LISTSECRETVERSIONSREQ']._serialized_start=239
  _globals['_LISTSECRETVERSIONSREQ']._serialized_end=284
  _globals['_LISTSECRETVERSIONSRESP']._serialized_start=286
  _globals['_LISTSECRETVERSIONSRESP']._serialized_end=328
  _globals['_SETSECRETREQ']._serialized_start=330
  _globals['_SETSECRETREQ']._serialized_end=390
  _globals['_SETSECRETRESP']._serialized_start=392
  _globals['_SETSECRETRESP']._serialized_end=424
  _globals['_DELETESECRETREQ']._serialized_start=426
  _globals['_DELETESECRETREQ']._serialized_end=465
  _globals['_DELETESECRETRESP']._serialized_start=467
  _globals['_DELETESECRETRESP']._serialized_end=485
  _globals['_DELETESECRETVERSIONREQ']._serialized_start=487
  _globals['_DELETESECRETVERSIONREQ']._serialized_end=559
  _globals['_DELETESECRETVERSIONRESP']._serialized_start=561
  _globals['_DELETESECRETVERSIONRESP']._serialized_end=586
  _globals['_SECRETSMANAGER']._serialized_start=589
  _globals['_SECRETSMANAGER']._serialized_end=1291
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import prodvana.proto.prodvana.common_config.parameters_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class PerReleaseChannelParameterValues(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    release_channel: builtins.str
    @property
    def parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterValue]: ...
    def __init__(
        self,
        *,
        release_channel: builtins.str = ...,
        parameters: collections.abc.Iterable[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterValue] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["parameters", b"parameters", "release_channel", b"release_channel"]) -> None: ...

global___PerReleaseChannelParameterValues = PerReleaseChannelParameterValues

class ServiceParameterValues(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMETERS_FIELD_NUMBER: builtins.int
    PER_RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    @property
    def parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterValue]: ...
    @property
    def per_release_channel(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PerReleaseChannelParameterValues]: ...
    def __init__(
        self,
        *,
        parameters: collections.abc.Iterable[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterValue] | None = ...,
        per_release_channel: collections.abc.Iterable[global___PerReleaseChannelParameterValues] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["parameters", b"parameters", "per_release_channel", b"per_release_channel"]) -> None: ...

global___ServiceParameterValues = ServiceParameterValues



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import prodvana.proto.prodvana.common_config.constants_pb2
import prodvana.proto.prodvana.common_config.env_pb2
import prodvana.proto.prodvana.common_config.maturity_pb2
import prodvana.proto.prodvana.labels.labels_pb2
import prodvana.proto.prodvana.pipelines.pipelines_pb2
import prodvana.proto.prodvana.protection.attachments_pb2
import prodvana.proto.prodvana.runtimes.runtimes_config_pb2
import prodvana.proto.prodvana.workflow.integration_config_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _RuntimeConnectionType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RuntimeConnectionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_RuntimeConnectionType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN_CONNECTION: _RuntimeConnectionType.ValueType  # 0
    LONG_LIVED_COMPUTE: _RuntimeConnectionType.ValueType  # 1
    EXTENSION: _RuntimeConnectionType.ValueType  # 2
    AWS_ECS: _RuntimeConnectionType.ValueType  # 3
    GOOGLE_CLOUD_RUN: _RuntimeConnectionType.ValueType  # 4

class RuntimeConnectionType(_RuntimeConnectionType, metaclass=_RuntimeConnectionTypeEnumTypeWrapper): ...

UNKNOWN_CONNECTION: RuntimeConnectionType.ValueType  # 0
LONG_LIVED_COMPUTE: RuntimeConnectionType.ValueType  # 1
EXTENSION: RuntimeConnectionType.ValueType  # 2
AWS_ECS: RuntimeConnectionType.ValueType  # 3
GOOGLE_CLOUD_RUN: RuntimeConnectionType.ValueType  # 4
global___RuntimeConnectionType = RuntimeConnectionType

class Policy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class DefaultEnvEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> prodvana.proto.prodvana.common_config.env_pb2.EnvValue: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: prodvana.proto.prodvana.common_config.env_pb2.EnvValue | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DEFAULT_ENV_FIELD_NUMBER: builtins.int
    @property
    def default_env(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue]: ...
    def __init__(
        self,
        *,
        default_env: collections.abc.Mapping[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_env", b"default_env"]) -> None: ...

global___Policy = Policy

class ReleaseChannelConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    ORDER_FIELD_NUMBER: builtins.int
    MATURITY_FIELD_NUMBER: builtins.int
    POLICY_FIELD_NUMBER: builtins.int
    RUNTIMES_FIELD_NUMBER: builtins.int
    DEPLOY_ANNOTATIONS_FIELD_NUMBER: builtins.int
    PRECONDITIONS_FIELD_NUMBER: builtins.int
    PROTECTIONS_FIELD_NUMBER: builtins.int
    CONVERGENCE_PROTECTIONS_FIELD_NUMBER: builtins.int
    SERVICE_INSTANCE_PROTECTIONS_FIELD_NUMBER: builtins.int
    CONSTANTS_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    DISABLE_ALL_PROTECTIONS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """intentionally does not reference cluster - this allows us to copy release channels across clusters via the same config"""
    group: builtins.str
    """if specified, this release channel is part of a group. This can affect how release channels are rendered on the Prodvana web interface."""
    order: builtins.int
    """deprecated"""
    maturity: prodvana.proto.prodvana.common_config.maturity_pb2.Maturity.ValueType
    """deprecated"""
    @property
    def policy(self) -> global___Policy: ...
    @property
    def runtimes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReleaseChannelRuntimeConfig]: ...
    @property
    def deploy_annotations(self) -> prodvana.proto.prodvana.workflow.integration_config_pb2.AnnotationsConfig: ...
    @property
    def preconditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Precondition]: ...
    @property
    def protections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.protection.attachments_pb2.ProtectionAttachmentConfig]: ...
    @property
    def convergence_protections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.protection.attachments_pb2.ProtectionAttachmentConfig]: ...
    @property
    def service_instance_protections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.protection.attachments_pb2.ProtectionAttachmentConfig]:
        """protections that all service instances in this release channel should get"""
    @property
    def constants(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.constants_pb2.Constant]:
        """constants made available in template substitutions"""
    @property
    def labels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.labels.labels_pb2.LabelDefinition]: ...
    disable_all_protections: builtins.bool
    """Disable all protections for this release channel - protections will not be created for any service instances in this release channel.
    This is useful for release channels that are used for testing or are not yet in production (e.g., fast creation of new tenants).
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        group: builtins.str = ...,
        order: builtins.int = ...,
        maturity: prodvana.proto.prodvana.common_config.maturity_pb2.Maturity.ValueType = ...,
        policy: global___Policy | None = ...,
        runtimes: collections.abc.Iterable[global___ReleaseChannelRuntimeConfig] | None = ...,
        deploy_annotations: prodvana.proto.prodvana.workflow.integration_config_pb2.AnnotationsConfig | None = ...,
        preconditions: collections.abc.Iterable[global___Precondition] | None = ...,
        protections: collections.abc.Iterable[prodvana.proto.prodvana.protection.attachments_pb2.ProtectionAttachmentConfig] | None = ...,
        convergence_protections: collections.abc.Iterable[prodvana.proto.prodvana.protection.attachments_pb2.ProtectionAttachmentConfig] | None = ...,
        service_instance_protections: collections.abc.Iterable[prodvana.proto.prodvana.protection.attachments_pb2.ProtectionAttachmentConfig] | None = ...,
        constants: collections.abc.Iterable[prodvana.proto.prodvana.common_config.constants_pb2.Constant] | None = ...,
        labels: collections.abc.Iterable[prodvana.proto.prodvana.labels.labels_pb2.LabelDefinition] | None = ...,
        disable_all_protections: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["deploy_annotations", b"deploy_annotations", "policy", b"policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["constants", b"constants", "convergence_protections", b"convergence_protections", "deploy_annotations", b"deploy_annotations", "disable_all_protections", b"disable_all_protections", "group", b"group", "labels", b"labels", "maturity", b"maturity", "name", b"name", "order", b"order", "policy", b"policy", "preconditions", b"preconditions", "protections", b"protections", "runtimes", b"runtimes", "service_instance_protections", b"service_instance_protections"]) -> None: ...

global___ReleaseChannelConfig = ReleaseChannelConfig

class Precondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class ReleaseChannelStable(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
        SELECTOR_FIELD_NUMBER: builtins.int
        ALLOW_EMPTY_FIELD_NUMBER: builtins.int
        release_channel: builtins.str
        selector: builtins.str
        allow_empty: builtins.bool
        """if selector is used, allow selector to return an empty list of release channels"""
        def __init__(
            self,
            *,
            release_channel: builtins.str = ...,
            selector: builtins.str = ...,
            allow_empty: builtins.bool = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["release_channel", b"release_channel", "selector", b"selector", "stable_oneof", b"stable_oneof"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["allow_empty", b"allow_empty", "release_channel", b"release_channel", "selector", b"selector", "stable_oneof", b"stable_oneof"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions.Literal["stable_oneof", b"stable_oneof"]) -> typing_extensions.Literal["release_channel", "selector"] | None: ...

    class ManualApproval(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NAME_FIELD_NUMBER: builtins.int
        DESCRIPTION_FIELD_NUMBER: builtins.int
        EVERY_ACTION_FIELD_NUMBER: builtins.int
        name: builtins.str
        description: builtins.str
        every_action: builtins.bool
        """request approval on every apply action, not just the first.
        only works for runtime extensions, will do nothing for kubernetes services.
        """
        def __init__(
            self,
            *,
            name: builtins.str = ...,
            description: builtins.str = ...,
            every_action: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "every_action", b"every_action", "name", b"name"]) -> None: ...

    class CustomTask(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TASK_NAME_FIELD_NUMBER: builtins.int
        CUSTOM_TASK_FIELD_NUMBER: builtins.int
        task_name: builtins.str
        @property
        def custom_task(self) -> prodvana.proto.prodvana.pipelines.pipelines_pb2.CustomTask: ...
        def __init__(
            self,
            *,
            task_name: builtins.str = ...,
            custom_task: prodvana.proto.prodvana.pipelines.pipelines_pb2.CustomTask | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["custom_task", b"custom_task"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["custom_task", b"custom_task", "task_name", b"task_name"]) -> None: ...

    class SharedManualApproval(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NAME_FIELD_NUMBER: builtins.int
        name: builtins.str
        def __init__(
            self,
            *,
            name: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

    RELEASE_CHANNEL_STABLE_FIELD_NUMBER: builtins.int
    MANUAL_APPROVAL_FIELD_NUMBER: builtins.int
    CUSTOM_TASK_FIELD_NUMBER: builtins.int
    SHARED_MANUAL_APPROVAL_FIELD_NUMBER: builtins.int
    @property
    def release_channel_stable(self) -> global___Precondition.ReleaseChannelStable: ...
    @property
    def manual_approval(self) -> global___Precondition.ManualApproval: ...
    @property
    def custom_task(self) -> global___Precondition.CustomTask: ...
    @property
    def shared_manual_approval(self) -> global___Precondition.SharedManualApproval: ...
    def __init__(
        self,
        *,
        release_channel_stable: global___Precondition.ReleaseChannelStable | None = ...,
        manual_approval: global___Precondition.ManualApproval | None = ...,
        custom_task: global___Precondition.CustomTask | None = ...,
        shared_manual_approval: global___Precondition.SharedManualApproval | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["custom_task", b"custom_task", "manual_approval", b"manual_approval", "precondition", b"precondition", "release_channel_stable", b"release_channel_stable", "shared_manual_approval", b"shared_manual_approval"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom_task", b"custom_task", "manual_approval", b"manual_approval", "precondition", b"precondition", "release_channel_stable", b"release_channel_stable", "shared_manual_approval", b"shared_manual_approval"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["precondition", b"precondition"]) -> typing_extensions.Literal["release_channel_stable", "manual_approval", "custom_task", "shared_manual_approval"] | None: ...

global___Precondition = Precondition

class ReleaseChannelRuntimeConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RUNTIME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CONTAINER_ORCHESTRATION_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    runtime: builtins.str
    name: builtins.str
    """Optional identifier for this runtime connection within this release channel,
    useful if the release channel has multiple runtimes of the same type.
    Defaults to the value of `runtime``.
    """
    @property
    def container_orchestration(self) -> prodvana.proto.prodvana.runtimes.runtimes_config_pb2.ContainerOrchestrationRuntime: ...
    type: global___RuntimeConnectionType.ValueType
    """set internally by prodvana, overridden even if set manually."""
    def __init__(
        self,
        *,
        runtime: builtins.str = ...,
        name: builtins.str = ...,
        container_orchestration: prodvana.proto.prodvana.runtimes.runtimes_config_pb2.ContainerOrchestrationRuntime | None = ...,
        type: global___RuntimeConnectionType.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["capability", b"capability", "container_orchestration", b"container_orchestration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["capability", b"capability", "container_orchestration", b"container_orchestration", "name", b"name", "runtime", b"runtime", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["capability", b"capability"]) -> typing_extensions.Literal["container_orchestration"] | None: ...

global___ReleaseChannelRuntimeConfig = ReleaseChannelRuntimeConfig

class ReleaseChannelGroupGeneratorConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    RUNTIME_SELECTOR_FIELD_NUMBER: builtins.int
    ALLOW_EMPTY_FIELD_NUMBER: builtins.int
    TEMPLATE_FIELD_NUMBER: builtins.int
    name: builtins.str
    runtime_selector: builtins.str
    """label selector for runtimes to generate release channels for.
    One release channel will be generated for each runtime that matches this selector.
    The selector will automatically be intersected with "@type=runtime".
    """
    allow_empty: builtins.bool
    """By default, if the runtime selector returns an empty list of runtimes, Prodvana will error out.
    Set allow_empty to true to explicitly allow the selector to return an empty list.
    """
    @property
    def template(self) -> global___ReleaseChannelConfig:
        """optionally customize how the release channel will be generated.
        Template variables .Builtins.Group an d.Builtins.Runtime are available.
        Any value specified here will be merged with:
        name: {{.Builtins.Group}}-{{.Builtins.Runtime.Name}}
        group: {{.Builtins.Group}}
        runtimes:
        - runtime: {{Builtins.Runtime.Name}}
        """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        runtime_selector: builtins.str = ...,
        allow_empty: builtins.bool = ...,
        template: global___ReleaseChannelConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["template", b"template"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_empty", b"allow_empty", "name", b"name", "runtime_selector", b"runtime_selector", "template", b"template"]) -> None: ...

global___ReleaseChannelGroupGeneratorConfig = ReleaseChannelGroupGeneratorConfig



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import prodvana.proto.prodvana.common_config.env_pb2
import prodvana.proto.prodvana.common_config.kubernetes_config_pb2
import prodvana.proto.prodvana.common_config.parameters_pb2
import prodvana.proto.prodvana.common_config.task_pb2
import prodvana.proto.prodvana.runtimes.runtimes_config_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Type:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Type.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN_TYPE: _Type.ValueType  # 0
    GLOBAL_USER_CREATED: _Type.ValueType  # 1
    EPHEMERAL: _Type.ValueType  # 2
    """one-off delivery extensions inlined into other configs"""

class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...

UNKNOWN_TYPE: Type.ValueType  # 0
GLOBAL_USER_CREATED: Type.ValueType  # 1
EPHEMERAL: Type.ValueType  # 2
"""one-off delivery extensions inlined into other configs"""
global___Type = Type

class DeliveryExtensionConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> prodvana.proto.prodvana.common_config.env_pb2.EnvValue: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: prodvana.proto.prodvana.common_config.env_pb2.EnvValue | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    TASK_CONFIG_FIELD_NUMBER: builtins.int
    KUBERNETES_CONFIG_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def task_config(self) -> prodvana.proto.prodvana.common_config.task_pb2.TaskConfig: ...
    @property
    def kubernetes_config(self) -> prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig: ...
    @property
    def parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterDefinition]: ...
    @property
    def env(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue]:
        """optional env variables to inject and override from exec_config"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        task_config: prodvana.proto.prodvana.common_config.task_pb2.TaskConfig | None = ...,
        kubernetes_config: prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig | None = ...,
        parameters: collections.abc.Iterable[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterDefinition] | None = ...,
        env: collections.abc.Mapping[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["exec_config", b"exec_config", "kubernetes_config", b"kubernetes_config", "task_config", b"task_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["env", b"env", "exec_config", b"exec_config", "kubernetes_config", b"kubernetes_config", "name", b"name", "parameters", b"parameters", "task_config", b"task_config"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["exec_config", b"exec_config"]) -> typing_extensions.Literal["task_config", "kubernetes_config"] | None: ...

global___DeliveryExtensionConfig = DeliveryExtensionConfig

class DeliveryExtensionInstanceRef(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterValue]: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        parameters: collections.abc.Iterable[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterValue] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "parameters", b"parameters"]) -> None: ...

global___DeliveryExtensionInstanceRef = DeliveryExtensionInstanceRef

class CompiledDeliveryExtensionInstanceConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> prodvana.proto.prodvana.common_config.env_pb2.EnvValue: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: prodvana.proto.prodvana.common_config.env_pb2.EnvValue | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DEFINITION_FIELD_NUMBER: builtins.int
    RUNTIME_EXECUTION_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    PARAMETER_VALUES_FIELD_NUMBER: builtins.int
    @property
    def definition(self) -> global___DeliveryExtensionConfig: ...
    @property
    def runtime_execution(self) -> prodvana.proto.prodvana.runtimes.runtimes_config_pb2.RuntimeExecutionConfig: ...
    @property
    def env(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue]:
        """The compiled environment for this attachment's context, e.g.  Release Channel."""
    @property
    def parameter_values(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterValue]:
        """TODO(naphat) custom task lifecycle

        compiled parameter values
        """
    def __init__(
        self,
        *,
        definition: global___DeliveryExtensionConfig | None = ...,
        runtime_execution: prodvana.proto.prodvana.runtimes.runtimes_config_pb2.RuntimeExecutionConfig | None = ...,
        env: collections.abc.Mapping[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue] | None = ...,
        parameter_values: collections.abc.Iterable[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterValue] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["definition", b"definition", "runtime_execution", b"runtime_execution"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["definition", b"definition", "env", b"env", "parameter_values", b"parameter_values", "runtime_execution", b"runtime_execution"]) -> None: ...

global___CompiledDeliveryExtensionInstanceConfig = CompiledDeliveryExtensionInstanceConfig



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class EfficiencyStat(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SAVED_LINES_FIELD_NUMBER: builtins.int
    MATERIALIZED_LINES_FIELD_NUMBER: builtins.int
    saved_lines: builtins.int
    """how many lines did Prodvana save you from writing? Computed by comparing materialized yaml to proto text format"""
    materialized_lines: builtins.int
    """how many lines of materialized config was either added, modified, or deleted?"""
    def __init__(
        self,
        *,
        saved_lines: builtins.int = ...,
        materialized_lines: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["materialized_lines", b"materialized_lines", "saved_lines", b"saved_lines"]) -> None: ...

global___EfficiencyStat = EfficiencyStat



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ConfigWritebackPath(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    DISPLAY_PATH_FIELD_NUMBER: builtins.int
    display_name: builtins.str
    """short, user-readable name of what this config is. May contain spaces."""
    display_path: builtins.str
    """will be HTTP if apiserver is configured with a http display path, otherwise will be a git ssh/local path"""
    def __init__(
        self,
        *,
        display_name: builtins.str = ...,
        display_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["display_name", b"display_name", "display_path", b"display_path"]) -> None: ...

global___ConfigWritebackPath = ConfigWritebackPath



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import prodvana.proto.prodvana.common_config.env_pb2
import prodvana.proto.prodvana.common_config.program_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ProgramChange(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___ProgramChange = ProgramChange

class StringParameterDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_VALUE_FIELD_NUMBER: builtins.int
    default_value: builtins.str
    def __init__(
        self,
        *,
        default_value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_value", b"default_value"]) -> None: ...

global___StringParameterDefinition = StringParameterDefinition

class DockerImageParameterDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Changes(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        PROGRAM_FIELD_NUMBER: builtins.int
        @property
        def program(self) -> global___ProgramChange: ...
        def __init__(
            self,
            *,
            program: global___ProgramChange | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["oneof", b"oneof", "program", b"program"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["oneof", b"oneof", "program", b"program"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions.Literal["oneof", b"oneof"]) -> typing_extensions.Literal["program"] | None: ...

    DEFAULT_TAG_FIELD_NUMBER: builtins.int
    IMAGE_REGISTRY_INFO_FIELD_NUMBER: builtins.int
    CHANGES_FIELD_NUMBER: builtins.int
    default_tag: builtins.str
    """can be omitted if parameter is required"""
    @property
    def image_registry_info(self) -> prodvana.proto.prodvana.common_config.program_pb2.ImageRegistryInfo: ...
    @property
    def changes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DockerImageParameterDefinition.Changes]: ...
    def __init__(
        self,
        *,
        default_tag: builtins.str = ...,
        image_registry_info: prodvana.proto.prodvana.common_config.program_pb2.ImageRegistryInfo | None = ...,
        changes: collections.abc.Iterable[global___DockerImageParameterDefinition.Changes] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["image_registry_info", b"image_registry_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["changes", b"changes", "default_tag", b"default_tag", "image_registry_info", b"image_registry_info"]) -> None: ...

global___DockerImageParameterDefinition = DockerImageParameterDefinition

class FixedReplicaChange(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___FixedReplicaChange = FixedReplicaChange

class IntParameterDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Changes(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        FIXED_REPLICA_FIELD_NUMBER: builtins.int
        @property
        def fixed_replica(self) -> global___FixedReplicaChange: ...
        def __init__(
            self,
            *,
            fixed_replica: global___FixedReplicaChange | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["fixed_replica", b"fixed_replica", "oneof", b"oneof"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["fixed_replica", b"fixed_replica", "oneof", b"oneof"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions.Literal["oneof", b"oneof"]) -> typing_extensions.Literal["fixed_replica"] | None: ...

    DEFAULT_VALUE_FIELD_NUMBER: builtins.int
    CHANGES_FIELD_NUMBER: builtins.int
    default_value: builtins.int
    @property
    def changes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IntParameterDefinition.Changes]: ...
    def __init__(
        self,
        *,
        default_value: builtins.int = ...,
        changes: collections.abc.Iterable[global___IntParameterDefinition.Changes] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["changes", b"changes", "default_value", b"default_value"]) -> None: ...

global___IntParameterDefinition = IntParameterDefinition

class SecretParameterDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SecretParameterDefinition = SecretParameterDefinition

class CommitParameterDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPOSITORY_FIELD_NUMBER: builtins.int
    BRANCH_FIELD_NUMBER: builtins.int
    repository: builtins.str
    branch: builtins.str
    """branch to pull commits from, defaults to `main`"""
    def __init__(
        self,
        *,
        repository: builtins.str = ...,
        branch: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch", b"branch", "repository", b"repository"]) -> None: ...

global___CommitParameterDefinition = CommitParameterDefinition

class BlobParameterDefinition(google.protobuf.message.Message):
    """A parameter pointing to a remote blob, stored inside Prodvana's BlobsManager interface.
    The value of the template variable will be the blob ID.
    When combined with `pvn-wrapper exec --in`, this parameter type can be used to make files manifest
    on disk.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___BlobParameterDefinition = BlobParameterDefinition

class ParameterDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STRING_FIELD_NUMBER: builtins.int
    DOCKER_IMAGE_FIELD_NUMBER: builtins.int
    INT_FIELD_NUMBER: builtins.int
    SECRET_FIELD_NUMBER: builtins.int
    COMMIT_FIELD_NUMBER: builtins.int
    BLOB_FIELD_NUMBER: builtins.int
    REQUIRED_FIELD_NUMBER: builtins.int
    name: builtins.str
    """parameter name, used in substitutions"""
    description: builtins.str
    """optional description for display purposes"""
    @property
    def string(self) -> global___StringParameterDefinition: ...
    @property
    def docker_image(self) -> global___DockerImageParameterDefinition: ...
    @property
    def int(self) -> global___IntParameterDefinition: ...
    @property
    def secret(self) -> global___SecretParameterDefinition: ...
    @property
    def commit(self) -> global___CommitParameterDefinition: ...
    @property
    def blob(self) -> global___BlobParameterDefinition: ...
    required: builtins.bool
    """next: 10"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        string: global___StringParameterDefinition | None = ...,
        docker_image: global___DockerImageParameterDefinition | None = ...,
        int: global___IntParameterDefinition | None = ...,
        secret: global___SecretParameterDefinition | None = ...,
        commit: global___CommitParameterDefinition | None = ...,
        blob: global___BlobParameterDefinition | None = ...,
        required: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["blob", b"blob", "commit", b"commit", "config_oneof", b"config_oneof", "docker_image", b"docker_image", "int", b"int", "secret", b"secret", "string", b"string"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["blob", b"blob", "commit", b"commit", "config_oneof", b"config_oneof", "description", b"description", "docker_image", b"docker_image", "int", b"int", "name", b"name", "required", b"required", "secret", b"secret", "string", b"string"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["config_oneof", b"config_oneof"]) -> typing_extensions.Literal["string", "docker_image", "int", "secret", "commit", "blob"] | None: ...

global___ParameterDefinition = ParameterDefinition

class SecretParameterValue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RAW_SECRET_FIELD_NUMBER: builtins.int
    SECRET_REF_FIELD_NUMBER: builtins.int
    raw_secret: builtins.str
    """Raw secret value"""
    @property
    def secret_ref(self) -> prodvana.proto.prodvana.common_config.env_pb2.Secret:
        """Existing secret reference."""
    def __init__(
        self,
        *,
        raw_secret: builtins.str = ...,
        secret_ref: prodvana.proto.prodvana.common_config.env_pb2.Secret | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["raw_secret", b"raw_secret", "secret_oneof", b"secret_oneof", "secret_ref", b"secret_ref"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["raw_secret", b"raw_secret", "secret_oneof", b"secret_oneof", "secret_ref", b"secret_ref"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["secret_oneof", b"secret_oneof"]) -> typing_extensions.Literal["raw_secret", "secret_ref"] | None: ...

global___SecretParameterValue = SecretParameterValue

class BlobParameterValue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INLINED_FIELD_NUMBER: builtins.int
    inlined: builtins.str
    def __init__(
        self,
        *,
        inlined: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["blob_oneof", b"blob_oneof", "inlined", b"inlined"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["blob_oneof", b"blob_oneof", "inlined", b"inlined"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["blob_oneof", b"blob_oneof"]) -> typing_extensions.Literal["inlined"] | None: ...

global___BlobParameterValue = BlobParameterValue

class ParameterValue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    STRING_FIELD_NUMBER: builtins.int
    INT_FIELD_NUMBER: builtins.int
    DOCKER_IMAGE_TAG_FIELD_NUMBER: builtins.int
    SECRET_FIELD_NUMBER: builtins.int
    COMMIT_FIELD_NUMBER: builtins.int
    BLOB_FIELD_NUMBER: builtins.int
    name: builtins.str
    string: builtins.str
    int: builtins.int
    docker_image_tag: builtins.str
    @property
    def secret(self) -> global___SecretParameterValue: ...
    commit: builtins.str
    @property
    def blob(self) -> global___BlobParameterValue: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        string: builtins.str = ...,
        int: builtins.int = ...,
        docker_image_tag: builtins.str = ...,
        secret: global___SecretParameterValue | None = ...,
        commit: builtins.str = ...,
        blob: global___BlobParameterValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["blob", b"blob", "commit", b"commit", "docker_image_tag", b"docker_image_tag", "int", b"int", "secret", b"secret", "string", b"string", "value_oneof", b"value_oneof"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["blob", b"blob", "commit", b"commit", "docker_image_tag", b"docker_image_tag", "int", b"int", "name", b"name", "secret", b"secret", "string", b"string", "value_oneof", b"value_oneof"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["value_oneof", b"value_oneof"]) -> typing_extensions.Literal["string", "int", "docker_image_tag", "secret", "commit", "blob"] | None: ...

global___ParameterValue = ParameterValue

class ParametersConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMETERS_FIELD_NUMBER: builtins.int
    @property
    def parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ParameterDefinition]: ...
    def __init__(
        self,
        *,
        parameters: collections.abc.Iterable[global___ParameterDefinition] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["parameters", b"parameters"]) -> None: ...

global___ParametersConfig = ParametersConfig



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import prodvana.proto.prodvana.application.application_manager_pb2

class ApplicationManagerStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    ConfigureApplication: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.application.application_manager_pb2.ConfigureApplicationReq,
        prodvana.proto.prodvana.application.application_manager_pb2.ConfigureApplicationResp,
    ]
    ValidateConfigureApplication: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.application.application_manager_pb2.ConfigureApplicationReq,
        prodvana.proto.prodvana.application.application_manager_pb2.ValidateConfigureApplicationResp,
    ]
    ListApplications: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.application.application_manager_pb2.ListApplicationsReq,
        prodvana.proto.prodvana.application.application_manager_pb2.ListApplicationsResp,
    ]
    GetApplicationConfig: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.application.application_manager_pb2.GetApplicationConfigReq,
        prodvana.proto.prodvana.application.application_manager_pb2.GetApplicationConfigResp,
    ]
    GetApplication: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.application.application_manager_pb2.GetApplicationReq,
        prodvana.proto.prodvana.application.application_manager_pb2.GetApplicationResp,
    ]
    DeleteApplication: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.application.application_manager_pb2.DeleteApplicationReq,
        prodvana.proto.prodvana.application.application_manager_pb2.DeleteApplicationResp,
    ]
    GetApplicationMetrics: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.application.application_manager_pb2.GetApplicationMetricsReq,
        prodvana.proto.prodvana.application.application_manager_pb2.GetApplicationMetricsResp,
    ]
    GetApplicationInsights: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.application.application_manager_pb2.GetApplicationInsightsReq,
        prodvana.proto.prodvana.application.application_manager_pb2.GetApplicationInsightsResp,
    ]
    SnoozeApplicationInsight: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.application.application_manager_pb2.SnoozeApplicationInsightReq,
        prodvana.proto.prodvana.application.application_manager_pb2.SnoozeApplicationInsightResp,
    ]
    GetApplicationMetadata: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.application.application_manager_pb2.GetApplicationMetadataReq,
        prodvana.proto.prodvana.application.application_manager_pb2.GetApplicationMetadataResp,
    ]
    """Get application metadata, useful for constructing edit workflows for metadata"""
    SetApplicationMetadata: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.application.application_manager_pb2.SetApplicationMetadataReq,
        prodvana.proto.prodvana.application.application_manager_pb2.SetApplicationMetadataResp,
    ]

class ApplicationManagerServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def ConfigureApplication(
        self,
        request: prodvana.proto.prodvana.application.application_manager_pb2.ConfigureApplicationReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.application.application_manager_pb2.ConfigureApplicationResp: ...
    @abc.abstractmethod
    def ValidateConfigureApplication(
        self,
        request: prodvana.proto.prodvana.application.application_manager_pb2.ConfigureApplicationReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.application.application_manager_pb2.ValidateConfigureApplicationResp: ...
    @abc.abstractmethod
    def ListApplications(
        self,
        request: prodvana.proto.prodvana.application.application_manager_pb2.ListApplicationsReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.application.application_manager_pb2.ListApplicationsResp: ...
    @abc.abstractmethod
    def GetApplicationConfig(
        self,
        request: prodvana.proto.prodvana.application.application_manager_pb2.GetApplicationConfigReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.application.application_manager_pb2.GetApplicationConfigResp: ...
    @abc.abstractmethod
    def GetApplication(
        self,
        request: prodvana.proto.prodvana.application.application_manager_pb2.GetApplicationReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.application.application_manager_pb2.GetApplicationResp: ...
    @abc.abstractmethod
    def DeleteApplication(
        self,
        request: prodvana.proto.prodvana.application.application_manager_pb2.DeleteApplicationReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.application.application_manager_pb2.DeleteApplicationResp: ...
    @abc.abstractmethod
    def GetApplicationMetrics(
        self,
        request: prodvana.proto.prodvana.application.application_manager_pb2.GetApplicationMetricsReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.application.application_manager_pb2.GetApplicationMetricsResp: ...
    @abc.abstractmethod
    def GetApplicationInsights(
        self,
        request: prodvana.proto.prodvana.application.application_manager_pb2.GetApplicationInsightsReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.application.application_manager_pb2.GetApplicationInsightsResp: ...
    @abc.abstractmethod
    def SnoozeApplicationInsight(
        self,
        request: prodvana.proto.prodvana.application.application_manager_pb2.SnoozeApplicationInsightReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.application.application_manager_pb2.SnoozeApplicationInsightResp: ...
    @abc.abstractmethod
    def GetApplicationMetadata(
        self,
        request: prodvana.proto.prodvana.application.application_manager_pb2.GetApplicationMetadataReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.application.application_manager_pb2.GetApplicationMetadataResp:
        """Get application metadata, useful for constructing edit workflows for metadata"""
    @abc.abstractmethod
    def SetApplicationMetadata(
        self,
        request: prodvana.proto.prodvana.application.application_manager_pb2.SetApplicationMetadataReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.application.application_manager_pb2.SetApplicationMetadataResp: ...

def add_ApplicationManagerServicer_to_server(servicer: ApplicationManagerServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import prodvana.proto.prodvana.protection.object_pb2
import prodvana.proto.prodvana.protection.protection_config_pb2
import prodvana.proto.prodvana.version.source_metadata_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ConfigureProtectionReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROTECTION_CONFIG_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    SOURCE_METADATA_FIELD_NUMBER: builtins.int
    @property
    def protection_config(self) -> prodvana.proto.prodvana.protection.protection_config_pb2.ProtectionConfig: ...
    source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType
    @property
    def source_metadata(self) -> prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata: ...
    def __init__(
        self,
        *,
        protection_config: prodvana.proto.prodvana.protection.protection_config_pb2.ProtectionConfig | None = ...,
        source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType = ...,
        source_metadata: prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["protection_config", b"protection_config", "source_metadata", b"source_metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["protection_config", b"protection_config", "source", b"source", "source_metadata", b"source_metadata"]) -> None: ...

global___ConfigureProtectionReq = ConfigureProtectionReq

class ConfigureProtectionResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROTECTION_ID_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    protection_id: builtins.str
    version: builtins.str
    def __init__(
        self,
        *,
        protection_id: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["protection_id", b"protection_id", "version", b"version"]) -> None: ...

global___ConfigureProtectionResp = ConfigureProtectionResp

class ValidateConfigureProtectionResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INPUT_CONFIG_FIELD_NUMBER: builtins.int
    COMPILED_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def input_config(self) -> prodvana.proto.prodvana.protection.protection_config_pb2.ProtectionConfig: ...
    @property
    def compiled_config(self) -> prodvana.proto.prodvana.protection.protection_config_pb2.ProtectionConfig: ...
    def __init__(
        self,
        *,
        input_config: prodvana.proto.prodvana.protection.protection_config_pb2.ProtectionConfig | None = ...,
        compiled_config: prodvana.proto.prodvana.protection.protection_config_pb2.ProtectionConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["compiled_config", b"compiled_config", "input_config", b"input_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compiled_config", b"compiled_config", "input_config", b"input_config"]) -> None: ...

global___ValidateConfigureProtectionResp = ValidateConfigureProtectionResp

class ListProtectionsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    page_token: builtins.str
    page_size: builtins.int
    def __init__(
        self,
        *,
        page_token: builtins.str = ...,
        page_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListProtectionsReq = ListProtectionsReq

class ListProtectionsResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROTECTIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    @property
    def protections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.protection.object_pb2.Protection]: ...
    next_page_token: builtins.str
    def __init__(
        self,
        *,
        protections: collections.abc.Iterable[prodvana.proto.prodvana.protection.object_pb2.Protection] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["next_page_token", b"next_page_token", "protections", b"protections"]) -> None: ...

global___ListProtectionsResp = ListProtectionsResp

class GetProtectionReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROTECTION_FIELD_NUMBER: builtins.int
    protection: builtins.str
    def __init__(
        self,
        *,
        protection: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["protection", b"protection"]) -> None: ...

global___GetProtectionReq = GetProtectionReq

class GetProtectionResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROTECTION_FIELD_NUMBER: builtins.int
    @property
    def protection(self) -> prodvana.proto.prodvana.protection.object_pb2.Protection: ...
    def __init__(
        self,
        *,
        protection: prodvana.proto.prodvana.protection.object_pb2.Protection | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["protection", b"protection"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["protection", b"protection"]) -> None: ...

global___GetProtectionResp = GetProtectionResp

class GetProtectionConfigReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROTECTION_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    protection: builtins.str
    version: builtins.str
    """omit to get latest version"""
    def __init__(
        self,
        *,
        protection: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["protection", b"protection", "version", b"version"]) -> None: ...

global___GetProtectionConfigReq = GetProtectionConfigReq

class GetProtectionConfigResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INPUT_CONFIG_FIELD_NUMBER: builtins.int
    COMPILED_CONFIG_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    @property
    def input_config(self) -> prodvana.proto.prodvana.protection.protection_config_pb2.ProtectionConfig: ...
    @property
    def compiled_config(self) -> prodvana.proto.prodvana.protection.protection_config_pb2.ProtectionConfig: ...
    version: builtins.str
    """next tag: 4"""
    def __init__(
        self,
        *,
        input_config: prodvana.proto.prodvana.protection.protection_config_pb2.ProtectionConfig | None = ...,
        compiled_config: prodvana.proto.prodvana.protection.protection_config_pb2.ProtectionConfig | None = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["compiled_config", b"compiled_config", "input_config", b"input_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compiled_config", b"compiled_config", "input_config", b"input_config", "version", b"version"]) -> None: ...

global___GetProtectionConfigResp = GetProtectionConfigResp

class GetProtectionAttachmentConfigReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ATTACHMENT_ID_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    attachment_id: builtins.str
    version: builtins.str
    """omit to get latest version"""
    def __init__(
        self,
        *,
        attachment_id: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["attachment_id", b"attachment_id", "version", b"version"]) -> None: ...

global___GetProtectionAttachmentConfigReq = GetProtectionAttachmentConfigReq

class GetProtectionAttachmentConfigResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    @property
    def config(self) -> prodvana.proto.prodvana.protection.protection_config_pb2.CompiledProtectionAttachmentConfig: ...
    version: builtins.str
    def __init__(
        self,
        *,
        config: prodvana.proto.prodvana.protection.protection_config_pb2.CompiledProtectionAttachmentConfig | None = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config", b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config", b"config", "version", b"version"]) -> None: ...

global___GetProtectionAttachmentConfigResp = GetProtectionAttachmentConfigResp



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/release/manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from prodvana.proto.prodvana.object import meta_pb2 as prodvana_dot_object_dot_meta__pb2
from prodvana.proto.prodvana.release import object_pb2 as prodvana_dot_release_dot_object__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eprodvana/release/manager.proto\x12\x10prodvana.release\x1a\x1cgoogle/api/annotations.proto\x1a\x1aprodvana/object/meta.proto\x1a\x1dprodvana/release/object.proto\x1a\x17validate/validate.proto\"^\n\x10RecordReleaseReq\x12\x39\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x1f.prodvana.release.ReleaseConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x0f\n\x07pending\x18\x02 \x01(\x08\">\n\x11RecordReleaseResp\x12)\n\x04meta\x18\x01 \x01(\x0b\x32\x1b.prodvana.object.ObjectMeta\"]\n\x16UpdateReleaseStatusReq\x12\x12\n\nrelease_id\x18\x01 \x01(\t\x12/\n\x06status\x18\x02 \x01(\x0e\x32\x1f.prodvana.release.ReleaseStatus\"J\n\x17UpdateReleaseStatusResp\x12/\n\x06status\x18\x01 \x01(\x0e\x32\x1f.prodvana.release.ReleaseStatus\"j\n\rReleaseFilter\x12\x10\n\x08services\x18\x01 \x03(\t\x12\x18\n\x10release_channels\x18\x02 \x03(\t\x12\x13\n\x0b\x61pplication\x18\x03 \x01(\t\x12\x18\n\x10\x64\x65sired_state_id\x18\x04 \x01(\t\"\xd3\x01\n\x0fListReleasesReq\x12\x30\n\x07\x66ilters\x18\x01 \x03(\x0b\x32\x1f.prodvana.release.ReleaseFilter\x12/\n\x06\x66ilter\x18\x02 \x01(\x0b\x32\x1f.prodvana.release.ReleaseFilter\x12\x1b\n\x13starting_release_id\x18\x03 \x01(\t\x12\x19\n\x11\x65nding_release_id\x18\x04 \x01(\t\x12\x12\n\npage_token\x18\x05 \x01(\t\x12\x11\n\tpage_size\x18\x06 \x01(\x05\"X\n\x10ListReleasesResp\x12+\n\x08releases\x18\x01 \x03(\x0b\x32\x19.prodvana.release.Release\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"a\n\nReleaseRef\x12\x14\n\nrelease_id\x18\x01 \x01(\tH\x00\x12\x31\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x1f.prodvana.release.ReleaseConfigH\x00\x42\n\n\x03ref\x12\x03\xf8\x42\x01\"\x84\x01\n\x11\x43ompareReleaseReq\x12;\n\x0bnew_release\x18\x01 \x01(\x0b\x32\x1c.prodvana.release.ReleaseRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x32\n\x0cprev_release\x18\x02 \x01(\x0b\x32\x1c.prodvana.release.ReleaseRef\"M\n\x12\x43ompareReleaseResp\x12\x37\n\ncomparison\x18\x01 \x01(\x0b\x32#.prodvana.release.ReleaseComparison\"\x82\x01\n\x11PreviewReleaseReq\x12\x39\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x1f.prodvana.release.ReleaseConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x32\n\x0cprev_release\x18\x02 \x01(\x0b\x32\x1c.prodvana.release.ReleaseRef\"@\n\x12PreviewReleaseResp\x12*\n\x07release\x18\x01 \x01(\x0b\x32\x19.prodvana.release.Release\"\xd1\x01\n\x14GetLatestReleasesReq\x12\x30\n\x07\x66ilters\x18\x01 \x03(\x0b\x32\x1f.prodvana.release.ReleaseFilter\x12/\n\x06\x66ilter\x18\x02 \x01(\x0b\x32\x1f.prodvana.release.ReleaseFilter\x12/\n\x06status\x18\x03 \x01(\x0e\x32\x1f.prodvana.release.ReleaseStatus\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x11\n\tpage_size\x18\x05 \x01(\x05\"]\n\x15GetLatestReleasesResp\x12+\n\x08releases\x18\x01 \x03(\x0b\x32\x19.prodvana.release.Release\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"r\n\x16ReleaseServiceInstance\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12 \n\x0frelease_channel\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\xdc\x01\n\x17\x43heckCommitInReleaseReq\x12\x1d\n\nrelease_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12V\n\x18release_service_instance\x18\x02 \x01(\x0b\x32(.prodvana.release.ReleaseServiceInstanceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00\x12\x1b\n\nrepository\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x17\n\x06\x63ommit\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x42\x14\n\rrelease_oneof\x12\x03\xf8\x42\x01\"\xa5\x01\n\x18\x43heckCommitInReleaseResp\x12\x41\n\x06result\x18\x01 \x01(\x0e\x32\x31.prodvana.release.CheckCommitInReleaseResp.Result\"F\n\x06Result\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0c\n\x08INCLUDED\x10\x01\x12\x0f\n\x0bNO_RELATION\x10\x02\x12\x10\n\x0cNOT_INCLUDED\x10\x03\x32\x80\x08\n\x0eReleaseManager\x12q\n\rRecordRelease\x12\".prodvana.release.RecordReleaseReq\x1a#.prodvana.release.RecordReleaseResp\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0c/v1/releases:\x01*\x12\x99\x01\n\x13UpdateReleaseStatus\x12(.prodvana.release.UpdateReleaseStatusReq\x1a).prodvana.release.UpdateReleaseStatusResp\"-\x82\xd3\xe4\x93\x02\'\"\"/v1/releases/{release_id=*}/status:\x01*\x12k\n\x0cListReleases\x12!.prodvana.release.ListReleasesReq\x1a\".prodvana.release.ListReleasesResp\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/v1/releases\x12_\n\x12ListReleasesStream\x12!.prodvana.release.ListReleasesReq\x1a\".prodvana.release.ListReleasesResp\"\x00\x30\x01\x12|\n\x0e\x43ompareRelease\x12#.prodvana.release.CompareReleaseReq\x1a$.prodvana.release.CompareReleaseResp\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/v1/releases/compare:\x01*\x12|\n\x0ePreviewRelease\x12#.prodvana.release.PreviewReleaseReq\x1a$.prodvana.release.PreviewReleaseResp\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/v1/releases/preview:\x01*\x12\x81\x01\n\x11GetLatestReleases\x12&.prodvana.release.GetLatestReleasesReq\x1a\'.prodvana.release.GetLatestReleasesResp\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/v1/releases/latest\x12\x90\x01\n\x14\x43heckCommitInRelease\x12).prodvana.release.CheckCommitInReleaseReq\x1a*.prodvana.release.CheckCommitInReleaseResp\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/releases/check_commitBLZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/releaseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.release.manager_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/release'
  _RECORDRELEASEREQ.fields_by_name['config']._options = None
  _RECORDRELEASEREQ.fields_by_name['config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _RELEASEREF.oneofs_by_name['ref']._options = None
  _RELEASEREF.oneofs_by_name['ref']._serialized_options = b'\370B\001'
  _COMPARERELEASEREQ.fields_by_name['new_release']._options = None
  _COMPARERELEASEREQ.fields_by_name['new_release']._serialized_options = b'\372B\005\212\001\002\020\001'
  _PREVIEWRELEASEREQ.fields_by_name['config']._options = None
  _PREVIEWRELEASEREQ.fields_by_name['config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _RELEASESERVICEINSTANCE.fields_by_name['application']._options = None
  _RELEASESERVICEINSTANCE.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _RELEASESERVICEINSTANCE.fields_by_name['service']._options = None
  _RELEASESERVICEINSTANCE.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _RELEASESERVICEINSTANCE.fields_by_name['release_channel']._options = None
  _RELEASESERVICEINSTANCE.fields_by_name['release_channel']._serialized_options = b'\372B\004r\002\020\001'
  _CHECKCOMMITINRELEASEREQ.oneofs_by_name['release_oneof']._options = None
  _CHECKCOMMITINRELEASEREQ.oneofs_by_name['release_oneof']._serialized_options = b'\370B\001'
  _CHECKCOMMITINRELEASEREQ.fields_by_name['release_id']._options = None
  _CHECKCOMMITINRELEASEREQ.fields_by_name['release_id']._serialized_options = b'\372B\004r\002\020\001'
  _CHECKCOMMITINRELEASEREQ.fields_by_name['release_service_instance']._options = None
  _CHECKCOMMITINRELEASEREQ.fields_by_name['release_service_instance']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CHECKCOMMITINRELEASEREQ.fields_by_name['repository']._options = None
  _CHECKCOMMITINRELEASEREQ.fields_by_name['repository']._serialized_options = b'\372B\004r\002\020\001'
  _CHECKCOMMITINRELEASEREQ.fields_by_name['commit']._options = None
  _CHECKCOMMITINRELEASEREQ.fields_by_name['commit']._serialized_options = b'\372B\004r\002\020\001'
  _RELEASEMANAGER.methods_by_name['RecordRelease']._options = None
  _RELEASEMANAGER.methods_by_name['RecordRelease']._serialized_options = b'\202\323\344\223\002\021\"\014/v1/releases:\001*'
  _RELEASEMANAGER.methods_by_name['UpdateReleaseStatus']._options = None
  _RELEASEMANAGER.methods_by_name['UpdateReleaseStatus']._serialized_options = b'\202\323\344\223\002\'\"\"/v1/releases/{release_id=*}/status:\001*'
  _RELEASEMANAGER.methods_by_name['ListReleases']._options = None
  _RELEASEMANAGER.methods_by_name['ListReleases']._serialized_options = b'\202\323\344\223\002\016\022\014/v1/releases'
  _RELEASEMANAGER.methods_by_name['CompareRelease']._options = None
  _RELEASEMANAGER.methods_by_name['CompareRelease']._serialized_options = b'\202\323\344\223\002\031\"\024/v1/releases/compare:\001*'
  _RELEASEMANAGER.methods_by_name['PreviewRelease']._options = None
  _RELEASEMANAGER.methods_by_name['PreviewRelease']._serialized_options = b'\202\323\344\223\002\031\"\024/v1/releases/preview:\001*'
  _RELEASEMANAGER.methods_by_name['GetLatestReleases']._options = None
  _RELEASEMANAGER.methods_by_name['GetLatestReleases']._serialized_options = b'\202\323\344\223\002\025\022\023/v1/releases/latest'
  _RELEASEMANAGER.methods_by_name['CheckCommitInRelease']._options = None
  _RELEASEMANAGER.methods_by_name['CheckCommitInRelease']._serialized_options = b'\202\323\344\223\002\033\022\031/v1/releases/check_commit'
  _globals['_RECORDRELEASEREQ']._serialized_start=166
  _globals['_RECORDRELEASEREQ']._serialized_end=260
  _globals['_RECORDRELEASERESP']._serialized_start=262
  _globals['_RECORDRELEASERESP']._serialized_end=324
  _globals['_UPDATERELEASESTATUSREQ']._serialized_start=326
  _globals['_UPDATERELEASESTATUSREQ']._serialized_end=419
  _globals['_UPDATERELEASESTATUSRESP']._serialized_start=421
  _globals['_UPDATERELEASESTATUSRESP']._serialized_end=495
  _globals['_RELEASEFILTER']._serialized_start=497
  _globals['_RELEASEFILTER']._serialized_end=603
  _globals['_LISTRELEASESREQ']._serialized_start=606
  _globals['_LISTRELEASESREQ']._serialized_end=817
  _globals['_LISTRELEASESRESP']._serialized_start=819
  _globals['_LISTRELEASESRESP']._serialized_end=907
  _globals['_RELEASEREF']._serialized_start=909
  _globals['_RELEASEREF']._serialized_end=1006
  _globals['_COMPARERELEASEREQ']._serialized_start=1009
  _globals['_COMPARERELEASEREQ']._serialized_end=1141
  _globals['_COMPARERELEASERESP']._serialized_start=1143
  _globals['_COMPARERELEASERESP']._serialized_end=1220
  _globals['_PREVIEWRELEASEREQ']._serialized_start=1223
  _globals['_PREVIEWRELEASEREQ']._serialized_end=1353
  _globals['_PREVIEWRELEASERESP']._serialized_start=1355
  _globals['_PREVIEWRELEASERESP']._serialized_end=1419
  _globals['_GETLATESTRELEASESREQ']._serialized_start=1422
  _globals['_GETLATESTRELEASESREQ']._serialized_end=1631
  _globals['_GETLATESTRELEASESRESP']._serialized_start=1633
  _globals['_GETLATESTRELEASESRESP']._serialized_end=1726
  _globals['_RELEASESERVICEINSTANCE']._serialized_start=1728
  _globals['_RELEASESERVICEINSTANCE']._serialized_end=1842
  _globals['_CHECKCOMMITINRELEASEREQ']._serialized_start=1845
  _globals['_CHECKCOMMITINRELEASEREQ']._serialized_end=2065
  _globals['_CHECKCOMMITINRELEASERESP']._serialized_start=2068
  _globals['_CHECKCOMMITINRELEASERESP']._serialized_end=2233
  _globals['_CHECKCOMMITINRELEASERESP_RESULT']._serialized_start=2163
  _globals['_CHECKCOMMITINRELEASERESP_RESULT']._serialized_end=2233
  _globals['_RELEASEMANAGER']._serialized_start=2236
  _globals['_RELEASEMANAGER']._serialized_end=3260
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import prodvana.proto.prodvana.common_config.env_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ListSecretsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListSecretsReq = ListSecretsReq

class ListSecretsResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRETS_FIELD_NUMBER: builtins.int
    @property
    def secrets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.env_pb2.Secret]: ...
    def __init__(
        self,
        *,
        secrets: collections.abc.Iterable[prodvana.proto.prodvana.common_config.env_pb2.Secret] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["secrets", b"secrets"]) -> None: ...

global___ListSecretsResp = ListSecretsResp

class ListSecretVersionsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    key: builtins.str
    def __init__(
        self,
        *,
        key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key"]) -> None: ...

global___ListSecretVersionsReq = ListSecretVersionsReq

class ListSecretVersionsResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSIONS_FIELD_NUMBER: builtins.int
    @property
    def versions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        versions: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["versions", b"versions"]) -> None: ...

global___ListSecretVersionsResp = ListSecretVersionsResp

class SetSecretReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

global___SetSecretReq = SetSecretReq

class SetSecretResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    version: builtins.str
    def __init__(
        self,
        *,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["version", b"version"]) -> None: ...

global___SetSecretResp = SetSecretResp

class DeleteSecretReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    key: builtins.str
    def __init__(
        self,
        *,
        key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key"]) -> None: ...

global___DeleteSecretReq = DeleteSecretReq

class DeleteSecretResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteSecretResp = DeleteSecretResp

class DeleteSecretVersionReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    key: builtins.str
    version: builtins.str
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "version", b"version"]) -> None: ...

global___DeleteSecretVersionReq = DeleteSecretVersionReq

class DeleteSecretVersionResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteSecretVersionResp = DeleteSecretVersionResp



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/common_config/rollback.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%prodvana/common_config/rollback.proto\x12\x16prodvana.common_config\"&\n\x12\x41utoRollbackConfig\x12\x10\n\x08\x64isabled\x18\x01 \x01(\x08\x42RZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_configb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.common_config.rollback_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_config'
  _globals['_AUTOROLLBACKCONFIG']._serialized_start=65
  _globals['_AUTOROLLBACKCONFIG']._serialized_end=103
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from prodvana.proto.prodvana.release import manager_pb2 as prodvana_dot_release_dot_manager__pb2


class ReleaseManagerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.RecordRelease = channel.unary_unary(
                '/prodvana.release.ReleaseManager/RecordRelease',
                request_serializer=prodvana_dot_release_dot_manager__pb2.RecordReleaseReq.SerializeToString,
                response_deserializer=prodvana_dot_release_dot_manager__pb2.RecordReleaseResp.FromString,
                )
        self.UpdateReleaseStatus = channel.unary_unary(
                '/prodvana.release.ReleaseManager/UpdateReleaseStatus',
                request_serializer=prodvana_dot_release_dot_manager__pb2.UpdateReleaseStatusReq.SerializeToString,
                response_deserializer=prodvana_dot_release_dot_manager__pb2.UpdateReleaseStatusResp.FromString,
                )
        self.ListReleases = channel.unary_unary(
                '/prodvana.release.ReleaseManager/ListReleases',
                request_serializer=prodvana_dot_release_dot_manager__pb2.ListReleasesReq.SerializeToString,
                response_deserializer=prodvana_dot_release_dot_manager__pb2.ListReleasesResp.FromString,
                )
        self.ListReleasesStream = channel.unary_stream(
                '/prodvana.release.ReleaseManager/ListReleasesStream',
                request_serializer=prodvana_dot_release_dot_manager__pb2.ListReleasesReq.SerializeToString,
                response_deserializer=prodvana_dot_release_dot_manager__pb2.ListReleasesResp.FromString,
                )
        self.CompareRelease = channel.unary_unary(
                '/prodvana.release.ReleaseManager/CompareRelease',
                request_serializer=prodvana_dot_release_dot_manager__pb2.CompareReleaseReq.SerializeToString,
                response_deserializer=prodvana_dot_release_dot_manager__pb2.CompareReleaseResp.FromString,
                )
        self.PreviewRelease = channel.unary_unary(
                '/prodvana.release.ReleaseManager/PreviewRelease',
                request_serializer=prodvana_dot_release_dot_manager__pb2.PreviewReleaseReq.SerializeToString,
                response_deserializer=prodvana_dot_release_dot_manager__pb2.PreviewReleaseResp.FromString,
                )
        self.GetLatestReleases = channel.unary_unary(
                '/prodvana.release.ReleaseManager/GetLatestReleases',
                request_serializer=prodvana_dot_release_dot_manager__pb2.GetLatestReleasesReq.SerializeToString,
                response_deserializer=prodvana_dot_release_dot_manager__pb2.GetLatestReleasesResp.FromString,
                )
        self.CheckCommitInRelease = channel.unary_unary(
                '/prodvana.release.ReleaseManager/CheckCommitInRelease',
                request_serializer=prodvana_dot_release_dot_manager__pb2.CheckCommitInReleaseReq.SerializeToString,
                response_deserializer=prodvana_dot_release_dot_manager__pb2.CheckCommitInReleaseResp.FromString,
                )


class ReleaseManagerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def RecordRelease(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateReleaseStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListReleases(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListReleasesStream(self, request, context):
        """page tokens arguments are ignored here
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CompareRelease(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PreviewRelease(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLatestReleases(self, request, context):
        """returns the latest releases for each (application, service, release channel) tuple.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CheckCommitInRelease(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ReleaseManagerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'RecordRelease': grpc.unary_unary_rpc_method_handler(
                    servicer.RecordRelease,
                    request_deserializer=prodvana_dot_release_dot_manager__pb2.RecordReleaseReq.FromString,
                    response_serializer=prodvana_dot_release_dot_manager__pb2.RecordReleaseResp.SerializeToString,
            ),
            'UpdateReleaseStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateReleaseStatus,
                    request_deserializer=prodvana_dot_release_dot_manager__pb2.UpdateReleaseStatusReq.FromString,
                    response_serializer=prodvana_dot_release_dot_manager__pb2.UpdateReleaseStatusResp.SerializeToString,
            ),
            'ListReleases': grpc.unary_unary_rpc_method_handler(
                    servicer.ListReleases,
                    request_deserializer=prodvana_dot_release_dot_manager__pb2.ListReleasesReq.FromString,
                    response_serializer=prodvana_dot_release_dot_manager__pb2.ListReleasesResp.SerializeToString,
            ),
            'ListReleasesStream': grpc.unary_stream_rpc_method_handler(
                    servicer.ListReleasesStream,
                    request_deserializer=prodvana_dot_release_dot_manager__pb2.ListReleasesReq.FromString,
                    response_serializer=prodvana_dot_release_dot_manager__pb2.ListReleasesResp.SerializeToString,
            ),
            'CompareRelease': grpc.unary_unary_rpc_method_handler(
                    servicer.CompareRelease,
                    request_deserializer=prodvana_dot_release_dot_manager__pb2.CompareReleaseReq.FromString,
                    response_serializer=prodvana_dot_release_dot_manager__pb2.CompareReleaseResp.SerializeToString,
            ),
            'PreviewRelease': grpc.unary_unary_rpc_method_handler(
                    servicer.PreviewRelease,
                    request_deserializer=prodvana_dot_release_dot_manager__pb2.PreviewReleaseReq.FromString,
                    response_serializer=prodvana_dot_release_dot_manager__pb2.PreviewReleaseResp.SerializeToString,
            ),
            'GetLatestReleases': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLatestReleases,
                    request_deserializer=prodvana_dot_release_dot_manager__pb2.GetLatestReleasesReq.FromString,
                    response_serializer=prodvana_dot_release_dot_manager__pb2.GetLatestReleasesResp.SerializeToString,
            ),
            'CheckCommitInRelease': grpc.unary_unary_rpc_method_handler(
                    servicer.CheckCommitInRelease,
                    request_deserializer=prodvana_dot_release_dot_manager__pb2.CheckCommitInReleaseReq.FromString,
                    response_serializer=prodvana_dot_release_dot_manager__pb2.CheckCommitInReleaseResp.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'prodvana.release.ReleaseManager', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ReleaseManager(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def RecordRelease(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.release.ReleaseManager/RecordRelease',
            prodvana_dot_release_dot_manager__pb2.RecordReleaseReq.SerializeToString,
            prodvana_dot_release_dot_manager__pb2.RecordReleaseResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateReleaseStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.release.ReleaseManager/UpdateReleaseStatus',
            prodvana_dot_release_dot_manager__pb2.UpdateReleaseStatusReq.SerializeToString,
            prodvana_dot_release_dot_manager__pb2.UpdateReleaseStatusResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListReleases(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.release.ReleaseManager/ListReleases',
            prodvana_dot_release_dot_manager__pb2.ListReleasesReq.SerializeToString,
            prodvana_dot_release_dot_manager__pb2.ListReleasesResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListReleasesStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/prodvana.release.ReleaseManager/ListReleasesStream',
            prodvana_dot_release_dot_manager__pb2.ListReleasesReq.SerializeToString,
            prodvana_dot_release_dot_manager__pb2.ListReleasesResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CompareRelease(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.release.ReleaseManager/CompareRelease',
            prodvana_dot_release_dot_manager__pb2.CompareReleaseReq.SerializeToString,
            prodvana_dot_release_dot_manager__pb2.CompareReleaseResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PreviewRelease(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.release.ReleaseManager/PreviewRelease',
            prodvana_dot_release_dot_manager__pb2.PreviewReleaseReq.SerializeToString,
            prodvana_dot_release_dot_manager__pb2.PreviewReleaseResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLatestReleases(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.release.ReleaseManager/GetLatestReleases',
            prodvana_dot_release_dot_manager__pb2.GetLatestReleasesReq.SerializeToString,
            prodvana_dot_release_dot_manager__pb2.GetLatestReleasesResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CheckCommitInRelease(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.release.ReleaseManager/CheckCommitInRelease',
            prodvana_dot_release_dot_manager__pb2.CheckCommitInReleaseReq.SerializeToString,
            prodvana_dot_release_dot_manager__pb2.CheckCommitInReleaseResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import prodvana.proto.prodvana.common_config.task_pb2
import prodvana.proto.prodvana.desired_state.model.desired_state_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Entity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    ROOT_DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    ANNOTATIONS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    SIMPLE_STATUS_FIELD_NUMBER: builtins.int
    STARTING_STATE_FIELD_NUMBER: builtins.int
    LAST_SEEN_STATE_FIELD_NUMBER: builtins.int
    DESIRED_STATE_FIELD_NUMBER: builtins.int
    TARGET_STATE_FIELD_NUMBER: builtins.int
    PRECONDITION_STATUSES_FIELD_NUMBER: builtins.int
    STATUS_EXPLANATIONS_FIELD_NUMBER: builtins.int
    LOGS_FIELD_NUMBER: builtins.int
    ACTION_EXPLANATION_FIELD_NUMBER: builtins.int
    LAST_UPDATE_TIMESTAMP_FIELD_NUMBER: builtins.int
    LAST_FETCHED_TIMESTAMP_FIELD_NUMBER: builtins.int
    LAST_APPLIED_TIMESTAMP_FIELD_NUMBER: builtins.int
    DEPENDENCIES_FIELD_NUMBER: builtins.int
    LIFECYCLE_FIELD_NUMBER: builtins.int
    MISSING_APPROVAL_FIELD_NUMBER: builtins.int
    @property
    def id(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier: ...
    desired_state_id: builtins.str
    root_desired_state_id: builtins.str
    @property
    def annotations(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Annotations: ...
    status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Status.ValueType
    simple_status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.SimpleStatus.ValueType
    @property
    def starting_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    @property
    def last_seen_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    @property
    def desired_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State:
        """the state we want to get to before calling convergence complete"""
    @property
    def target_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State:
        """the state we are actually going to apply. when preconditions are met, target state = desired state, otherwise, target state = previous desired state"""
    @property
    def precondition_statuses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ConditionState]: ...
    @property
    def status_explanations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.StatusExplanation]: ...
    @property
    def logs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.DebugLog]: ...
    @property
    def action_explanation(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ActionExplanation: ...
    @property
    def last_update_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """when the entity state last changed"""
    @property
    def last_fetched_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """when prodvana last fetched entity state, best effort"""
    @property
    def last_applied_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """when prodvana last applied state for this entity, best effort"""
    @property
    def dependencies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier]: ...
    lifecycle: prodvana.proto.prodvana.common_config.task_pb2.TaskLifecycle.ValueType
    @property
    def missing_approval(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.MissingApproval:
        """next tag: 21"""
    def __init__(
        self,
        *,
        id: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier | None = ...,
        desired_state_id: builtins.str = ...,
        root_desired_state_id: builtins.str = ...,
        annotations: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Annotations | None = ...,
        status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Status.ValueType = ...,
        simple_status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.SimpleStatus.ValueType = ...,
        starting_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        last_seen_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        desired_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        target_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        precondition_statuses: collections.abc.Iterable[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ConditionState] | None = ...,
        status_explanations: collections.abc.Iterable[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.StatusExplanation] | None = ...,
        logs: collections.abc.Iterable[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.DebugLog] | None = ...,
        action_explanation: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ActionExplanation | None = ...,
        last_update_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_fetched_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_applied_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        dependencies: collections.abc.Iterable[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier] | None = ...,
        lifecycle: prodvana.proto.prodvana.common_config.task_pb2.TaskLifecycle.ValueType = ...,
        missing_approval: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.MissingApproval | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["action_explanation", b"action_explanation", "annotations", b"annotations", "desired_state", b"desired_state", "id", b"id", "last_applied_timestamp", b"last_applied_timestamp", "last_fetched_timestamp", b"last_fetched_timestamp", "last_seen_state", b"last_seen_state", "last_update_timestamp", b"last_update_timestamp", "missing_approval", b"missing_approval", "starting_state", b"starting_state", "target_state", b"target_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action_explanation", b"action_explanation", "annotations", b"annotations", "dependencies", b"dependencies", "desired_state", b"desired_state", "desired_state_id", b"desired_state_id", "id", b"id", "last_applied_timestamp", b"last_applied_timestamp", "last_fetched_timestamp", b"last_fetched_timestamp", "last_seen_state", b"last_seen_state", "last_update_timestamp", b"last_update_timestamp", "lifecycle", b"lifecycle", "logs", b"logs", "missing_approval", b"missing_approval", "precondition_statuses", b"precondition_statuses", "root_desired_state_id", b"root_desired_state_id", "simple_status", b"simple_status", "starting_state", b"starting_state", "status", b"status", "status_explanations", b"status_explanations", "target_state", b"target_state"]) -> None: ...

global___Entity = Entity

class EntityGraph(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROOT_FIELD_NUMBER: builtins.int
    ENTITIES_FIELD_NUMBER: builtins.int
    @property
    def root(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier: ...
    @property
    def entities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Entity]: ...
    def __init__(
        self,
        *,
        root: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier | None = ...,
        entities: collections.abc.Iterable[global___Entity] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["root", b"root"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["entities", b"entities", "root", b"root"]) -> None: ...

global___EntityGraph = EntityGraph



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/common_config/retry.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from prodvana.proto.prodvana.common_config import notification_pb2 as prodvana_dot_common__config_dot_notification__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"prodvana/common_config/retry.proto\x12\x16prodvana.common_config\x1a\x17validate/validate.proto\x1a\x1egoogle/protobuf/duration.proto\x1a)prodvana/common_config/notification.proto\"m\n\x0cNotification\x12\x43\n\x0f\x63onfig_override\x18\x01 \x01(\x0b\x32*.prodvana.common_config.NotificationConfig\x12\x18\n\x07message\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\xc1\x01\n\x0bRetryConfig\x12\x41\n\x12max_retry_duration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00H\x00\x12\x17\n\rretry_forever\x18\x02 \x01(\x08H\x00\x12H\n\x1a\x66irst_failure_notification\x18\x03 \x01(\x0b\x32$.prodvana.common_config.NotificationB\x0c\n\x05limit\x12\x03\xf8\x42\x01\x42RZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_configb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.common_config.retry_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_config'
  _NOTIFICATION.fields_by_name['message']._options = None
  _NOTIFICATION.fields_by_name['message']._serialized_options = b'\372B\004r\002\020\001'
  _RETRYCONFIG.oneofs_by_name['limit']._options = None
  _RETRYCONFIG.oneofs_by_name['limit']._serialized_options = b'\370B\001'
  _RETRYCONFIG.fields_by_name['max_retry_duration']._options = None
  _RETRYCONFIG.fields_by_name['max_retry_duration']._serialized_options = b'\372B\005\252\001\002*\000'
  _globals['_NOTIFICATION']._serialized_start=162
  _globals['_NOTIFICATION']._serialized_end=271
  _globals['_RETRYCONFIG']._serialized_start=274
  _globals['_RETRYCONFIG']._serialized_end=467
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/delivery_extension/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2
from prodvana.proto.prodvana.common_config import task_pb2 as prodvana_dot_common__config_dot_task__pb2
from prodvana.proto.prodvana.common_config import env_pb2 as prodvana_dot_common__config_dot_env__pb2
from prodvana.proto.prodvana.common_config import kubernetes_config_pb2 as prodvana_dot_common__config_dot_kubernetes__config__pb2
from prodvana.proto.prodvana.common_config import parameters_pb2 as prodvana_dot_common__config_dot_parameters__pb2
from prodvana.proto.prodvana.runtimes import runtimes_config_pb2 as prodvana_dot_runtimes_dot_runtimes__config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(prodvana/delivery_extension/config.proto\x12\x1bprodvana.delivery_extension\x1a\x17validate/validate.proto\x1a!prodvana/common_config/task.proto\x1a prodvana/common_config/env.proto\x1a.prodvana/common_config/kubernetes_config.proto\x1a\'prodvana/common_config/parameters.proto\x1a\'prodvana/runtimes/runtimes_config.proto\"\xfe\x03\n\x17\x44\x65liveryExtensionConfig\x12:\n\x04name\x18\x01 \x01(\tB,\xfa\x42)r\'\x10\x00\x18?2!^[a-z]?([a-z0-9-]*[a-z0-9]){0,1}$\x12\x39\n\x0btask_config\x18\x02 \x01(\x0b\x32\".prodvana.common_config.TaskConfigH\x00\x12\x45\n\x11kubernetes_config\x18\x03 \x01(\x0b\x32(.prodvana.common_config.KubernetesConfigH\x00\x12N\n\nparameters\x18\x04 \x03(\x0b\x32+.prodvana.common_config.ParameterDefinitionB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x12s\n\x03\x65nv\x18\x05 \x03(\x0b\x32=.prodvana.delivery_extension.DeliveryExtensionConfig.EnvEntryB\'\xfa\x42$\x9a\x01!\x18\x01\"\x1dr\x1b\x32\x19^[a-zA-Z_]+[a-zA-Z0-9_]*$\x1aL\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .prodvana.common_config.EnvValue:\x02\x38\x01\x42\x12\n\x0b\x65xec_config\x12\x03\xf8\x42\x01\"\x95\x01\n\x1c\x44\x65liveryExtensionInstanceRef\x12\x39\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^[a-z]([a-z0-9-]*[a-z0-9]){0,1}$\x12:\n\nparameters\x18\x03 \x03(\x0b\x32&.prodvana.common_config.ParameterValue\"\xcf\x03\n\'CompiledDeliveryExtensionInstanceConfig\x12H\n\ndefinition\x18\x01 \x01(\x0b\x32\x34.prodvana.delivery_extension.DeliveryExtensionConfig\x12\x44\n\x11runtime_execution\x18\x02 \x01(\x0b\x32).prodvana.runtimes.RuntimeExecutionConfig\x12\x83\x01\n\x03\x65nv\x18\x03 \x03(\x0b\x32M.prodvana.delivery_extension.CompiledDeliveryExtensionInstanceConfig.EnvEntryB\'\xfa\x42$\x9a\x01!\x18\x01\"\x1dr\x1b\x32\x19^[a-zA-Z_]+[a-zA-Z0-9_]*$\x12@\n\x10parameter_values\x18\x04 \x03(\x0b\x32&.prodvana.common_config.ParameterValue\x1aL\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .prodvana.common_config.EnvValue:\x02\x38\x01*@\n\x04Type\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\x17\n\x13GLOBAL_USER_CREATED\x10\x01\x12\r\n\tEPHEMERAL\x10\x02\x42WZUgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/delivery_extensionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.delivery_extension.config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZUgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/delivery_extension'
  _DELIVERYEXTENSIONCONFIG_ENVENTRY._options = None
  _DELIVERYEXTENSIONCONFIG_ENVENTRY._serialized_options = b'8\001'
  _DELIVERYEXTENSIONCONFIG.oneofs_by_name['exec_config']._options = None
  _DELIVERYEXTENSIONCONFIG.oneofs_by_name['exec_config']._serialized_options = b'\370B\001'
  _DELIVERYEXTENSIONCONFIG.fields_by_name['name']._options = None
  _DELIVERYEXTENSIONCONFIG.fields_by_name['name']._serialized_options = b'\372B)r\'\020\000\030?2!^[a-z]?([a-z0-9-]*[a-z0-9]){0,1}$'
  _DELIVERYEXTENSIONCONFIG.fields_by_name['parameters']._options = None
  _DELIVERYEXTENSIONCONFIG.fields_by_name['parameters']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _DELIVERYEXTENSIONCONFIG.fields_by_name['env']._options = None
  _DELIVERYEXTENSIONCONFIG.fields_by_name['env']._serialized_options = b'\372B$\232\001!\030\001\"\035r\0332\031^[a-zA-Z_]+[a-zA-Z0-9_]*$'
  _DELIVERYEXTENSIONINSTANCEREF.fields_by_name['name']._options = None
  _DELIVERYEXTENSIONINSTANCEREF.fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^[a-z]([a-z0-9-]*[a-z0-9]){0,1}$'
  _COMPILEDDELIVERYEXTENSIONINSTANCECONFIG_ENVENTRY._options = None
  _COMPILEDDELIVERYEXTENSIONINSTANCECONFIG_ENVENTRY._serialized_options = b'8\001'
  _COMPILEDDELIVERYEXTENSIONINSTANCECONFIG.fields_by_name['env']._options = None
  _COMPILEDDELIVERYEXTENSIONINSTANCECONFIG.fields_by_name['env']._serialized_options = b'\372B$\232\001!\030\001\"\035r\0332\031^[a-zA-Z_]+[a-zA-Z0-9_]*$'
  _globals['_TYPE']._serialized_start=1428
  _globals['_TYPE']._serialized_end=1492
  _globals['_DELIVERYEXTENSIONCONFIG']._serialized_start=298
  _globals['_DELIVERYEXTENSIONCONFIG']._serialized_end=808
  _globals['_DELIVERYEXTENSIONCONFIG_ENVENTRY']._serialized_start=712
  _globals['_DELIVERYEXTENSIONCONFIG_ENVENTRY']._serialized_end=788
  _globals['_DELIVERYEXTENSIONINSTANCEREF']._serialized_start=811
  _globals['_DELIVERYEXTENSIONINSTANCEREF']._serialized_end=960
  _globals['_COMPILEDDELIVERYEXTENSIONINSTANCECONFIG']._serialized_start=963
  _globals['_COMPILEDDELIVERYEXTENSIONINSTANCECONFIG']._serialized_end=1426
  _globals['_COMPILEDDELIVERYEXTENSIONINSTANCECONFIG_ENVENTRY']._serialized_start=712
  _globals['_COMPILEDDELIVERYEXTENSIONINSTANCECONFIG_ENVENTRY']._serialized_end=788
# @@protoc_insertion_point(module_scope)
